==> assert-is-square-matrix-0.0.5.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isSquareMatrix

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Test if a value is a 2-dimensional [ndarray][@stdlib/ndarray/ctor]-like object having equal dimensions.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-square-matrix
```

</section>

<section class="usage">

## Usage

```javascript
var isSquareMatrix = require( '@stdlib/assert-is-square-matrix' );
```

#### isSquareMatrix( value )

Tests if a value is a 2-dimensional [ndarray][@stdlib/ndarray/ctor]-like object having equal dimensions.

```javascript
var ndarray = require( '@stdlib/ndarray-ctor' );

var arr = ndarray( 'generic', [ 0, 0, 0, 0 ], [ 2, 2 ], [ 2, 1 ], 0, 'row-major' );
var bool = isSquareMatrix( arr );
// returns true
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var ndarray = require( '@stdlib/ndarray-ctor' );
var isSquareMatrix = require( '@stdlib/assert-is-square-matrix' );

var arr = ndarray( 'generic', [ 0, 0, 0, 0 ], [ 2, 2 ], [ 2, 1 ], 0, 'row-major' );
var out = isSquareMatrix( arr );
// returns true

out = isSquareMatrix( [ 1, 2, 3, 4 ] );
// returns false

out = isSquareMatrix( {} );
// returns false

out = isSquareMatrix( null );
// returns false
```

</section>

<!-- /.examples -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-square-matrix.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-square-matrix

[test-image]: https://github.com/stdlib-js/assert-is-square-matrix/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/assert-is-square-matrix/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-square-matrix/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-square-matrix?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-square-matrix.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-square-matrix/main

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-square-matrix/main/LICENSE

[@stdlib/ndarray/ctor]: https://www.npmjs.com/package/@stdlib/ndarray-ctor

</section>

<!-- /.links -->

==> assert-is-square-matrix-0.0.6.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isSquareMatrix

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Test if a value is a 2-dimensional [ndarray][@stdlib/ndarray/ctor]-like object having equal dimensions.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-square-matrix
```

</section>

<section class="usage">

## Usage

```javascript
var isSquareMatrix = require( '@stdlib/assert-is-square-matrix' );
```

#### isSquareMatrix( value )

Tests if a value is a 2-dimensional [ndarray][@stdlib/ndarray/ctor]-like object having equal dimensions.

```javascript
var ndarray = require( '@stdlib/ndarray-ctor' );

var arr = ndarray( 'generic', [ 0, 0, 0, 0 ], [ 2, 2 ], [ 2, 1 ], 0, 'row-major' );
var bool = isSquareMatrix( arr );
// returns true
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var ndarray = require( '@stdlib/ndarray-ctor' );
var isSquareMatrix = require( '@stdlib/assert-is-square-matrix' );

var arr = ndarray( 'generic', [ 0, 0, 0, 0 ], [ 2, 2 ], [ 2, 1 ], 0, 'row-major' );
var out = isSquareMatrix( arr );
// returns true

out = isSquareMatrix( [ 1, 2, 3, 4 ] );
// returns false

out = isSquareMatrix( {} );
// returns false

out = isSquareMatrix( null );
// returns false
```

</section>

<!-- /.examples -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

* * *

## See Also

-   <span class="package-name">[`@stdlib/assert/is-matrix-like`][@stdlib/assert/is-matrix-like]</span><span class="delimiter">: </span><span class="description">test if a value is a 2-dimensional ndarray-like object.</span>
-   <span class="package-name">[`@stdlib/assert/is-symmetric-matrix`][@stdlib/assert/is-symmetric-matrix]</span><span class="delimiter">: </span><span class="description">test if a value is a symmetric matrix.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2022. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-square-matrix.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-square-matrix

[test-image]: https://github.com/stdlib-js/assert-is-square-matrix/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/assert-is-square-matrix/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-square-matrix/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-square-matrix?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-square-matrix.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-square-matrix/main

-->

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/assert-is-square-matrix/tree/deno
[umd-url]: https://github.com/stdlib-js/assert-is-square-matrix/tree/umd
[esm-url]: https://github.com/stdlib-js/assert-is-square-matrix/tree/esm

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-square-matrix/main/LICENSE

[@stdlib/ndarray/ctor]: https://www.npmjs.com/package/@stdlib/ndarray-ctor

<!-- <related-links> -->

[@stdlib/assert/is-matrix-like]: https://www.npmjs.com/package/@stdlib/assert-is-matrix-like

[@stdlib/assert/is-symmetric-matrix]: https://www.npmjs.com/package/@stdlib/assert-is-symmetric-matrix

<!-- </related-links> -->

</section>

<!-- /.links -->
